==> samurai-graph-src-0.1.2.zip: samurai-graph-src-0.1.2/src/jp/riken/brain/ni/samuraigraph/application/SGFileChooserWizardDialog.java <==
/*
 * 쐬: 2004/06/29
 *
 * ̐ꂽRg̑}ev[gύX邽
 * EBhE > ݒ > Java > R[h > R[hƃRg
 */
package jp.riken.brain.ni.samuraigraph.application;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.text.*;
import jp.riken.brain.ni.samuraigraph.base.*;
import jp.riken.brain.ni.samuraigraph.data.*;
import jp.riken.brain.ni.samuraigraph.figure.*;
import jp.riken.brain.ni.samuraigraph.figure.java2d.*;


/**
 * @author kuromaru
 *
 * ̐ꂽRg̑}ev[gύX邽
 * EBhE > ݒ > Java > R[h > R[hƃRg
 */
public class SGFileChooserWizardDialog extends SGWizardDialog
{

	/**
	 * 
	 */
	protected JFileChooser mFileChooser = new JFileChooser();



	/** Creates new form SGFileChooserWizardDialog */
	public SGFileChooserWizardDialog(java.awt.Frame parent, boolean modal)
	{
		super(parent, modal);
	}


	/**
	 * 
	 * t@C`[UJ
	 * ̓fBNg
	 * @return
	 */
	protected ArrayList openFileChooser()
	{
System.out.println("<< openFileChooser >>");

		//
		this.mFileChooser.setCurrentDirectory( new File( PATH_NAME ) );

//System.out.println(pathName);
//System.out.println("aaa");

		// show open dialog
		int ret = this.mFileChooser.showOpenDialog(this);

//System.out.println("bbb");

		ArrayList fileList = new ArrayList();
		switch( ret )
		{
			// selected
			case JFileChooser.APPROVE_OPTION :
			{
				if( this.mFileChooser.isMultiSelectionEnabled() )
				{
					File[] files = this.mFileChooser.getSelectedFiles();
					for( int ii=0; ii<files.length; ii++ )
					{
						fileList.add( files[ii] );
					}
				}
				else
				{
					fileList.add( this.mFileChooser.getSelectedFile() );
				}
				break;
			}

			// canceled
			case JFileChooser.CANCEL_OPTION :
			{
				break;
			}

			// error
			case JFileChooser.ERROR_OPTION :
			{
				throw new Error();
			}

			default :
			{
				
			}
		}

//System.out.println("ccc");

//System.out.println(fileList);

		return fileList;

	}








}

==> samurai-graph-src-0.2.0.zip: samurai-graph-src-0.2.0/src/jp/riken/brain/ni/samuraigraph/application/SGFileChooserWizardDialog.java <==
/*
 * 쐬: 2004/06/29
 *
 * ̐ꂽRg̑}ev[gύX邽
 * EBhE > ݒ > Java > R[h > R[hƃRg
 */
package jp.riken.brain.ni.samuraigraph.application;

import java.util.*;
import java.awt.*;
import java.awt.event.*;
import java.io.*;
import javax.swing.*;
import javax.swing.event.*;
import javax.swing.text.*;
import jp.riken.brain.ni.samuraigraph.base.*;
import jp.riken.brain.ni.samuraigraph.data.*;
import jp.riken.brain.ni.samuraigraph.figure.*;
import jp.riken.brain.ni.samuraigraph.figure.java2d.*;


/**
 * @author kuromaru
 *
 * ̐ꂽRg̑}ev[gύX邽
 * EBhE > ݒ > Java > R[h > R[hƃRg
 */
public abstract class SGFileChooserWizardDialog extends SGWizardDialog
{

	/**
	 * 
	 */
	protected JFileChooser mFileChooser = new JFileChooser();


	/**
	 * 
	 */
	public SGFileChooserWizardDialog()
	{
		super();
	}


	/** Creates new form SGFileChooserWizardDialog */
	public SGFileChooserWizardDialog(java.awt.Frame parent, boolean modal)
	{
		super(parent, modal);
	}


	/**
	 * 
	 * t@C`[UJ
	 * ̓fBNg
	 * @return
	 */
	protected ArrayList openFileChooser()
	{
		//
		this.mFileChooser.setCurrentDirectory( new File( PATH_NAME ) );

		// show open dialog
		int ret = this.mFileChooser.showOpenDialog(this);

		ArrayList fileList = new ArrayList();
		switch( ret )
		{
			// selected
			case JFileChooser.APPROVE_OPTION :
			{
				if( this.mFileChooser.isMultiSelectionEnabled() )
				{
					File[] files = this.mFileChooser.getSelectedFiles();
					for( int ii=0; ii<files.length; ii++ )
					{
						fileList.add( files[ii] );
					}
				}
				else
				{
					fileList.add( this.mFileChooser.getSelectedFile() );
				}
				break;
			}

			// canceled
			case JFileChooser.CANCEL_OPTION :
			{
				break;
			}

			// error
			case JFileChooser.ERROR_OPTION :
			{
				throw new Error();
			}

			default :
			{
				
			}
		}

		return fileList;

	}



}
